package com.tecnavia.firebaseanalytics

import android.content.Context
import com.facebook.react.bridge.Arguments
import com.facebook.react.bridge.Promise
import com.facebook.react.bridge.ReactApplicationContext
import com.facebook.react.bridge.ReactContextBaseJavaModule
import com.facebook.react.bridge.ReactMethod
import com.facebook.react.bridge.ReadableMap
import com.google.android.gms.tasks.Tasks
import com.google.firebase.FirebaseApp
import com.google.firebase.analytics.FirebaseAnalytics
import org.json.JSONObject

class FirebaseAnalyticsModule (context: ReactApplicationContext) : ReactContextBaseJavaModule(context) {
    private var _userId: String? = null;

    override fun getName(): String {
        return "FirebaseAnalytics"
    }

    @ReactMethod
    fun logEvent(name: String, data: ReadableMap, promise: Promise){
        Tasks.call {
            try {
                val bundle = Arguments.toBundle(data)
                FirebaseAnalytics.getInstance(reactApplicationContext)
                    .logEvent(name, bundle)
                promise.resolve(Arguments.createMap())
            }catch (e: Exception) {
                promise.reject(e)
            }
        }
    }

    @ReactMethod
    fun setAnalyticsCollectionEnabled(enabled: Boolean, promise: Promise){
        Tasks.call {
            try{
                FirebaseAnalytics.getInstance(reactApplicationContext)
                    .setAnalyticsCollectionEnabled(enabled)
                promise.resolve(Arguments.createMap())
            }catch (e: Exception) {
                promise.reject(e)
            }
        }
    }

    @ReactMethod
    fun setUserId(userId: String?, promise: Promise){
        Tasks.call {
            try{
                _userId = userId
                FirebaseAnalytics.getInstance(reactApplicationContext).setUserId(userId)
                promise.resolve(Arguments.createMap())
            }catch (e: Exception) {
                promise.reject(e)
            }
        }
    }

    /**
     * Sets the duration of inactivity that terminates the current session. The default value is 1800000 (30 minutes).
     */
    @ReactMethod
    fun setSessionTimeoutDuration(milliseconds: Long, promise: Promise){
        Tasks.call{
            try {
                FirebaseAnalytics.getInstance(reactApplicationContext).setSessionTimeoutDuration(milliseconds)
                promise.resolve(Arguments.createMap())
            }catch (e: Exception) {
                promise.reject(e)
            }
        }
    }

    /**
     * Clears all analytics data for this app from the device and resets the app instance id.
     */
    @ReactMethod
    fun resetAnalyticsData(promise: Promise){
        Tasks.call{
            try {
                FirebaseAnalytics.getInstance(reactApplicationContext).resetAnalyticsData()
                promise.resolve(Arguments.createMap())
            }catch (e: Exception) {
                promise.reject(e)
            }
        }
    }

    @ReactMethod
    fun getInstance(promise: Promise){
        try {
            FirebaseAnalytics.getInstance(reactApplicationContext).appInstanceId.addOnCompleteListener { task ->
                if (task.isSuccessful) {
                    promise.resolve(task.result)
                } else {
                    promise.reject(task.exception)
                }
            }
        }catch (e: Exception){
            promise.reject(e)
        }
    }
}