import { NativeModules } from "react-native";
import { eventNameValidator, eventParamsValidator, screenObjectValidator } from "./utils/event-validator";
import { isBoolean, isNumber } from "./utils/validators";
const Native = NativeModules.FirebaseAnalytics;
export class FirebaseAnalytics {
  async logEvent(name) {
    let params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    if (eventNameValidator(name) && eventParamsValidator(params)) {
      return Native.logEvent(name, params);
    }
    return Promise.reject(new Error("something went wrong on tracking event"));
  }
  async logScreenView(object) {
    if (screenObjectValidator(object)) {
      return this.logEvent("screen_view", object);
    }
    return Promise.reject(new Error("something went wrong on tracking screen"));
  }
  async setAnalyticsCollectionEnabled(enabled) {
    if (!isBoolean(enabled)) {
      throw new Error("setAnatlyticsCollectionEnabled 'enabled' expected a boolean value.");
    }
    return Native.setAnalyticsCollectionEnabled(enabled);
  }
  async setUserId(userId) {
    return Native.setUserId(userId);
  }
  async setSessionTimeoutDuration() {
    let milliseconds = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 1800000;
    if (!isNumber(milliseconds)) {
      throw new Error("firebase.analytics().setSessionTimeoutDuration(*) 'milliseconds' expected a number value.");
    }
    if (milliseconds < 0) {
      throw new Error("firebase.analytics().setSessionTimeoutDuration(*) 'milliseconds' expected a positive number value.");
    }
    return Native.setSessionTimeoutDuration(milliseconds);
  }
  async resetAnalyticsData() {
    return Native.resetAnalyticsData();
  }
}
//# sourceMappingURL=analytics.js.map