import { RESERVED_EVENT_NAMES } from "./reserved-events";
import { isAlphaNumericUnderscore, isObject, isString } from "./validators";
export function eventNameValidator(name) {
  if (!isString(name)) {
    throw new Error("logEvent name expected a string value.");
  }
  if (RESERVED_EVENT_NAMES.includes(name)) {
    throw new Error("logEvent name is reserved and can't be used.");
  }
  if (!isAlphaNumericUnderscore(name) || name.length > 40) {
    throw new Error(`logEvent name '${name}' should contain 1 to 40 alphanumeric characters or underscores.`);
  }
  return true;
}
export function eventParamsValidator(params) {
  if (!isObject(params)) {
    throw new Error("logEvent 'params' expected an object value.");
  }
  if (params && Object.keys(params).length > 25) {
    throw new Error("logEvent 'params' maximum number of parameters exceeded (25).");
  }
  return true;
}
export function screenObjectValidator(object) {
  if (!isObject(object)) {
    throw new Error("logScreenView 'object' expected an object value.");
  }
  if (!isString(object.screen_name)) {
    throw new Error("logScreenView 'object' expected screen_name");
  }
  return true;
}
//# sourceMappingURL=event-validator.js.map