const AlphaNumericUnderscore = /^[a-zA-Z0-9_]+$/;
const UrlValid = /^(http|https):\/\/[^ "]+$/;
export function objectKeyValuesAreStrings(object) {
  if (!isObject(object)) {
    return false;
  }
  const entries = Object.entries(object);
  for (let i = 0; i < entries.length; i++) {
    const entry = entries[i];
    if (!isString(entry === null || entry === void 0 ? void 0 : entry[0]) || !isString(entry === null || entry === void 0 ? void 0 : entry[1])) {
      return false;
    }
  }
  return true;
}
export function isNull(value) {
  return value === null;
}
export function isObject(value) {
  return value ? typeof value === "object" && !Array.isArray(value) && !isNull(value) : false;
}
export function isDate(value) {
  // https://stackoverflow.com/a/44198641
  return value instanceof Date || !isNaN(value);
}
export function isFunction(value) {
  return typeof value === "function";
}
export function isString(value) {
  return typeof value === "string";
}
export function isNumber(value) {
  return typeof value === "number";
}
export function isFinite(value) {
  return Number.isFinite(value);
}
export function isInteger(value) {
  return Number.isInteger(value);
}
export function isBoolean(value) {
  return typeof value === "boolean";
}
export function isArray(value) {
  return Array.isArray(value);
}
export function isUndefined(value) {
  return typeof value === "undefined";
}
export function isAlphaNumericUnderscore(value) {
  return AlphaNumericUnderscore.test(value);
}
export function isValidUrl(url) {
  return UrlValid.test(url);
}
export function isOneOf(value) {
  let oneOf = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  if (!isArray(oneOf)) {
    return false;
  }
  return oneOf.includes(value);
}
export function noop() {
  // noop-🐈
}
//# sourceMappingURL=validators.js.map